@@ -1,6 +1,6 @@
 import React from 'react';
 import { shallow } from 'enzyme';
-import { BigValue, Props } from './BigValue';
+import { BigValue, Props, SingleStatDisplayMode } from './BigValue';
 import { getTheme } from '../../themes/index';
 
 jest.mock('jquery', () => ({
@@ -11,6 +11,7 @@ const setup = (propOverrides?: object) => {
   const props: Props = {
     height: 300,
     width: 300,
+    displayMode: SingleStatDisplayMode.Classic,
     value: {
       text: '25',
       numeric: 25,
@@ -29,7 +30,7 @@ const setup = (propOverrides?: object) => {
   };
 };
 
-describe('Render BarGauge with basic options', () => {
+describe('Render SingleStat with basic options', () => {
   it('should render', () => {
     const { wrapper } = setup();
     expect(wrapper).toBeDefined();
