@@ -3,12 +3,11 @@ package rendering
 import (
 	"context"
 	"fmt"
+	plugin "github.com/hashicorp/go-plugin"
 	"net/url"
 	"os"
 	"path/filepath"
 
-	plugin "github.com/hashicorp/go-plugin"
-
 	pluginModel "github.com/grafana/grafana-plugin-model/go/renderer"
 	"github.com/grafana/grafana/pkg/infra/log"
 	"github.com/grafana/grafana/pkg/middleware"
@@ -93,6 +92,14 @@ func (rs *RenderingService) Run(ctx context.Context) error {
 	return err
 }
 
+func (rs *RenderingService) RenderErrorImage(err error) (*RenderResult, error) {
+	imgUrl := "public/img/rendering_error.png"
+
+	return &RenderResult{
+		FilePath: filepath.Join(setting.HomePath, imgUrl),
+	}, nil
+}
+
 func (rs *RenderingService) Render(ctx context.Context, opts Opts) (*RenderResult, error) {
 	if rs.inProgressCount > opts.ConcurrentLimit {
 		return &RenderResult{
@@ -112,9 +119,17 @@ func (rs *RenderingService) Render(ctx context.Context, opts Opts) (*RenderResul
 	return nil, fmt.Errorf("No renderer found")
 }
 
-func (rs *RenderingService) getFilePathForNewImage() string {
-	pngPath, _ := filepath.Abs(filepath.Join(rs.Cfg.ImagesDir, util.GetRandomString(20)))
-	return pngPath + ".png"
+func (rs *RenderingService) getFilePathForNewImage() (string, error) {
+	rand, err := util.GetRandomString(20)
+	if err != nil {
+		return "", err
+	}
+	pngPath, err := filepath.Abs(filepath.Join(rs.Cfg.ImagesDir, rand))
+	if err != nil {
+		return "", err
+	}
+
+	return pngPath + ".png", nil
 }
 
 func (rs *RenderingService) getURL(path string) string {
@@ -131,6 +146,6 @@ func (rs *RenderingService) getURL(path string) string {
 	return fmt.Sprintf("%s://%s:%s/%s&render=1", setting.Protocol, rs.domain, setting.HttpPort, path)
 }
 
-func (rs *RenderingService) getRenderKey(orgId, userId int64, orgRole models.RoleType) string {
+func (rs *RenderingService) getRenderKey(orgId, userId int64, orgRole models.RoleType) (string, error) {
 	return middleware.AddRenderAuthKey(orgId, userId, orgRole)
 }
