@@ -68,7 +68,8 @@ func TestMySQL(t *testing.T) {
 		Convey("Given a table with different native data types", func() {
 			if exists, err := sess.IsTableExist("mysql_types"); err != nil || exists {
 				So(err, ShouldBeNil)
-				sess.DropTable("mysql_types")
+				err = sess.DropTable("mysql_types")
+				So(err, ShouldBeNil)
 			}
 
 			sql := "CREATE TABLE `mysql_types` ("
@@ -181,7 +182,8 @@ func TestMySQL(t *testing.T) {
 
 			if exist, err := sess.IsTableExist(metric{}); err != nil || exist {
 				So(err, ShouldBeNil)
-				sess.DropTable(metric{})
+				err = sess.DropTable(metric{})
+				So(err, ShouldBeNil)
 			}
 			err := sess.CreateTable(metric{})
 			So(err, ShouldBeNil)
@@ -413,7 +415,8 @@ func TestMySQL(t *testing.T) {
 
 			if exist, err := sess.IsTableExist(metric_values{}); err != nil || exist {
 				So(err, ShouldBeNil)
-				sess.DropTable(metric_values{})
+				err = sess.DropTable(metric_values{})
+				So(err, ShouldBeNil)
 			}
 			err := sess.CreateTable(metric_values{})
 			So(err, ShouldBeNil)
@@ -788,7 +791,8 @@ func TestMySQL(t *testing.T) {
 
 			if exist, err := sess.IsTableExist(event{}); err != nil || exist {
 				So(err, ShouldBeNil)
-				sess.DropTable(event{})
+				err = sess.DropTable(event{})
+				So(err, ShouldBeNil)
 			}
 			err := sess.CreateTable(event{})
 			So(err, ShouldBeNil)
