@@ -1,8 +1,8 @@
-import AzureMonitorDatasource from '../datasource';
+import Datasource from '../datasource';
+import { DataFrame, toUtc } from '@grafana/data';
+import { TemplateSrv } from 'app/features/templating/template_srv';
 // @ts-ignore
 import Q from 'q';
-import { TemplateSrv } from 'app/features/templating/template_srv';
-import { toUtc } from '@grafana/data';
 
 describe('AppInsightsDatasource', () => {
   const ctx: any = {
@@ -17,7 +17,7 @@ describe('AppInsightsDatasource', () => {
       url: 'http://appinsightsapi',
     };
 
-    ctx.ds = new AzureMonitorDatasource(ctx.instanceSettings, ctx.backendSrv, ctx.templateSrv, ctx.$q);
+    ctx.ds = new Datasource(ctx.instanceSettings, ctx.backendSrv, ctx.templateSrv, ctx.$q);
   });
 
   describe('When performing testDatasource', () => {
@@ -108,7 +108,121 @@ describe('AppInsightsDatasource', () => {
     });
   });
 
-  describe('When performing query', () => {
+  describe('When performing raw query', () => {
+    const queryString =
+      'metrics ' +
+      '| where $__timeFilter(timestamp) ' +
+      '| where name == "testMetrics" ' +
+      '| summarize max=max(valueMax) by bin(timestamp, $__interval), partition';
+
+    const options = {
+      range: {
+        from: toUtc('2017-08-22T20:00:00Z'),
+        to: toUtc('2017-08-22T23:59:00Z'),
+      },
+      targets: [
+        {
+          apiVersion: '2016-09-01',
+          refId: 'A',
+          queryType: 'Application Insights',
+          appInsights: {
+            rawQuery: true,
+            rawQueryString: queryString,
+            timeColumn: 'timestamp',
+            valueColumn: 'max',
+            segmentColumn: undefined as string,
+          },
+        },
+      ],
+    };
+
+    describe('with no grouping', () => {
+      const response: any = {
+        results: {
+          A: {
+            refId: 'A',
+            meta: {},
+            series: [
+              {
+                name: 'PrimaryResult',
+                points: [[2.2075, 1558278660000]],
+              },
+            ],
+            tables: null,
+          },
+        },
+      };
+
+      beforeEach(() => {
+        ctx.backendSrv.datasourceRequest = (options: any) => {
+          expect(options.url).toContain('/api/tsdb/query');
+          expect(options.data.queries.length).toBe(1);
+          expect(options.data.queries[0].refId).toBe('A');
+          expect(options.data.queries[0].appInsights.rawQueryString).toEqual(queryString);
+          expect(options.data.queries[0].appInsights.timeColumn).toEqual('timestamp');
+          expect(options.data.queries[0].appInsights.valueColumn).toEqual('max');
+          expect(options.data.queries[0].appInsights.segmentColumn).toBeUndefined();
+          return ctx.$q.when({ data: response, status: 200 });
+        };
+      });
+
+      it('should return a list of datapoints', () => {
+        return ctx.ds.query(options).then((results: any) => {
+          expect(results.data.length).toBe(1);
+          const data = results.data[0] as DataFrame;
+          expect(data.name).toEqual('PrimaryResult');
+          expect(data.fields[0].values.length).toEqual(1);
+          expect(data.fields[1].values.get(0)).toEqual(1558278660000);
+          expect(data.fields[0].values.get(0)).toEqual(2.2075);
+        });
+      });
+    });
+
+    describe('with grouping', () => {
+      const response: any = {
+        results: {
+          A: {
+            refId: 'A',
+            meta: {},
+            series: [
+              {
+                name: 'paritionA',
+                points: [[2.2075, 1558278660000]],
+              },
+            ],
+            tables: null,
+          },
+        },
+      };
+
+      beforeEach(() => {
+        options.targets[0].appInsights.segmentColumn = 'partition';
+        ctx.backendSrv.datasourceRequest = (options: any) => {
+          expect(options.url).toContain('/api/tsdb/query');
+          expect(options.data.queries.length).toBe(1);
+          expect(options.data.queries[0].refId).toBe('A');
+          expect(options.data.queries[0].appInsights.rawQueryString).toEqual(queryString);
+          expect(options.data.queries[0].appInsights.timeColumn).toEqual('timestamp');
+          expect(options.data.queries[0].appInsights.valueColumn).toEqual('max');
+          expect(options.data.queries[0].appInsights.segmentColumn).toEqual('partition');
+          return ctx.$q.when({ data: response, status: 200 });
+        };
+      });
+
+      it('should return a list of datapoints', () => {
+        return ctx.ds.query(options).then((results: any) => {
+          expect(results.data.length).toBe(1);
+          const data = results.data[0] as DataFrame;
+          expect(data.name).toEqual('paritionA');
+          expect(data.fields[0].values.length).toEqual(1);
+          expect(data.fields[1].values.get(0)).toEqual(1558278660000);
+          expect(data.fields[0].values.get(0)).toEqual(2.2075);
+        });
+      });
+    });
+  });
+
+  describe('When performing metric query', () => {
     const options = {
       range: {
         from: toUtc('2017-08-22T20:00:00Z'),
@@ -121,30 +235,37 @@ describe('AppInsightsDatasource', () => {
           queryType: 'Application Insights',
           appInsights: {
             metricName: 'exceptions/server',
-            groupBy: '',
-            timeGrainType: 'none',
-            timeGrain: '',
-            timeGrainUnit: '',
-            alias: '',
+            dimension: '',
+            timeGrain: 'none',
           },
         },
       ],
     };
 
     describe('and with a single value', () => {
-      const response = {
-        value: {
-          start: '2017-08-30T15:53:58.845Z',
-          end: '2017-09-06T15:53:58.845Z',
-          'exceptions/server': {
-            sum: 100,
+      const response: any = {
+        results: {
+          A: {
+            refId: 'A',
+            meta: {},
+            series: [
+              {
+                name: 'exceptions/server',
+                points: [[2.2075, 1558278660000]],
+              },
+            ],
+            tables: null,
           },
         },
       };
 
       beforeEach(() => {
-        ctx.backendSrv.datasourceRequest = (options: { url: string }) => {
-          expect(options.url).toContain('/metrics/exceptions/server');
+        ctx.backendSrv.datasourceRequest = (options: any) => {
+          expect(options.url).toContain('/api/tsdb/query');
+          expect(options.data.queries.length).toBe(1);
+          expect(options.data.queries[0].refId).toBe('A');
+          expect(options.data.queries[0].appInsights.rawQueryString).toBeUndefined();
+          expect(options.data.queries[0].appInsights.metricName).toBe('exceptions/server');
           return ctx.$q.when({ data: response, status: 200 });
         };
       });
@@ -152,46 +273,39 @@ describe('AppInsightsDatasource', () => {
       it('should return a single datapoint', () => {
         return ctx.ds.query(options).then((results: any) => {
           expect(results.data.length).toBe(1);
-          expect(results.data[0].datapoints.length).toBe(1);
-          expect(results.data[0].target).toEqual('exceptions/server');
-          expect(results.data[0].datapoints[0][1]).toEqual(1504713238845);
-          expect(results.data[0].datapoints[0][0]).toEqual(100);
+          const data = results.data[0] as DataFrame;
+          expect(data.name).toEqual('exceptions/server');
+          expect(data.fields[1].values.get(0)).toEqual(1558278660000);
+          expect(data.fields[0].values.get(0)).toEqual(2.2075);
         });
       });
     });
 
     describe('and with an interval group and without a segment group by', () => {
-      const response = {
-        value: {
-          start: '2017-08-30T15:53:58.845Z',
-          end: '2017-09-06T15:53:58.845Z',
-          interval: 'PT1H',
-          segments: [
-            {
-              start: '2017-08-30T15:53:58.845Z',
-              end: '2017-08-30T16:00:00.000Z',
-              'exceptions/server': {
-                sum: 3,
+      const response: any = {
+        results: {
+          A: {
+            refId: 'A',
+            meta: {},
+            series: [
+              {
+                name: 'exceptions/server',
+                points: [[3, 1504108800000], [6, 1504112400000]],
               },
-            },
-            {
-              start: '2017-08-30T16:00:00.000Z',
-              end: '2017-08-30T17:00:00.000Z',
-              'exceptions/server': {
-                sum: 66,
-              },
-            },
-          ],
+            ],
+            tables: null,
+          },
         },
       };
 
       beforeEach(() => {
-        options.targets[0].appInsights.timeGrainType = 'specific';
-        options.targets[0].appInsights.timeGrain = '30';
-        options.targets[0].appInsights.timeGrainUnit = 'minute';
-        ctx.backendSrv.datasourceRequest = (options: { url: string }) => {
-          expect(options.url).toContain('/metrics/exceptions/server');
-          expect(options.url).toContain('interval=PT30M');
+        options.targets[0].appInsights.timeGrain = 'PT30M';
+        ctx.backendSrv.datasourceRequest = (options: any) => {
+          expect(options.url).toContain('/api/tsdb/query');
+          expect(options.data.queries[0].refId).toBe('A');
+          expect(options.data.queries[0].appInsights.rawQueryString).toBeUndefined();
+          expect(options.data.queries[0].appInsights.metricName).toBe('exceptions/server');
+          expect(options.data.queries[0].appInsights.timeGrain).toBe('PT30M');
           return ctx.$q.when({ data: response, status: 200 });
         };
       });
@@ -199,108 +313,68 @@ describe('AppInsightsDatasource', () => {
       it('should return a list of datapoints', () => {
         return ctx.ds.query(options).then((results: any) => {
           expect(results.data.length).toBe(1);
-          expect(results.data[0].datapoints.length).toBe(2);
-          expect(results.data[0].target).toEqual('exceptions/server');
-          expect(results.data[0].datapoints[0][1]).toEqual(1504108800000);
-          expect(results.data[0].datapoints[0][0]).toEqual(3);
-          expect(results.data[0].datapoints[1][1]).toEqual(1504112400000);
-          expect(results.data[0].datapoints[1][0]).toEqual(66);
+          const data = results.data[0] as DataFrame;
+          expect(data.name).toEqual('exceptions/server');
+          expect(data.fields[0].values.length).toEqual(2);
+          expect(data.fields[1].values.get(0)).toEqual(1504108800000);
+          expect(data.fields[0].values.get(0)).toEqual(3);
+          expect(data.fields[1].values.get(1)).toEqual(1504112400000);
+          expect(data.fields[0].values.get(1)).toEqual(6);
         });
       });
     });
 
     describe('and with a group by', () => {
-      const response = {
-        value: {
-          start: '2017-08-30T15:53:58.845Z',
-          end: '2017-09-06T15:53:58.845Z',
-          interval: 'PT1H',
-          segments: [
-            {
-              start: '2017-08-30T15:53:58.845Z',
-              end: '2017-08-30T16:00:00.000Z',
-              segments: [
-                {
-                  'exceptions/server': {
-                    sum: 10,
-                  },
-                  'client/city': 'Miami',
-                },
-                {
-                  'exceptions/server': {
-                    sum: 1,
-                  },
-                  'client/city': 'San Jose',
-                },
-              ],
-            },
-            {
-              start: '2017-08-30T16:00:00.000Z',
-              end: '2017-08-30T17:00:00.000Z',
-              segments: [
-                {
-                  'exceptions/server': {
-                    sum: 20,
-                  },
-                  'client/city': 'Miami',
-                },
-                {
-                  'exceptions/server': {
-                    sum: 2,
-                  },
-                  'client/city': 'San Antonio',
-                },
-              ],
-            },
-          ],
+      const response: any = {
+        results: {
+          A: {
+            refId: 'A',
+            meta: {},
+            series: [
+              {
+                name: 'exceptions/server{client/city="Miami"}',
+                points: [[10, 1504108800000], [20, 1504112400000]],
+              },
+              {
+                name: 'exceptions/server{client/city="San Antonio"}',
+                points: [[1, 1504108800000], [2, 1504112400000]],
+              },
+            ],
+            tables: null,
+          },
         },
       };
 
       describe('and with no alias specified', () => {
         beforeEach(() => {
-          options.targets[0].appInsights.groupBy = 'client/city';
+          options.targets[0].appInsights.dimension = 'client/city';
 
-          ctx.backendSrv.datasourceRequest = (options: { url: string }) => {
-            expect(options.url).toContain('/metrics/exceptions/server');
-            expect(options.url).toContain('segment=client/city');
+          ctx.backendSrv.datasourceRequest = (options: any) => {
+            expect(options.url).toContain('/api/tsdb/query');
+            expect(options.data.queries[0].appInsights.rawQueryString).toBeUndefined();
+            expect(options.data.queries[0].appInsights.metricName).toBe('exceptions/server');
+            expect(options.data.queries[0].appInsights.dimension).toBe('client/city');
             return ctx.$q.when({ data: response, status: 200 });
           };
         });
 
         it('should return a list of datapoints', () => {
           return ctx.ds.query(options).then((results: any) => {
-            expect(results.data.length).toBe(3);
-            expect(results.data[0].datapoints.length).toBe(2);
-            expect(results.data[0].target).toEqual('exceptions/server{client/city="Miami"}');
-            expect(results.data[0].datapoints[0][1]).toEqual(1504108800000);
-            expect(results.data[0].datapoints[0][0]).toEqual(10);
-            expect(results.data[0].datapoints[1][1]).toEqual(1504112400000);
-            expect(results.data[0].datapoints[1][0]).toEqual(20);
-          });
-        });
-      });
-
-      describe('and with an alias specified', () => {
-        beforeEach(() => {
-          options.targets[0].appInsights.groupBy = 'client/city';
-          options.targets[0].appInsights.alias = '{{metric}} + {{groupbyname}} + {{groupbyvalue}}';
-
-          ctx.backendSrv.datasourceRequest = (options: { url: string }) => {
-            expect(options.url).toContain('/metrics/exceptions/server');
-            expect(options.url).toContain('segment=client/city');
-            return ctx.$q.when({ data: response, status: 200 });
-          };
-        });
-
-        it('should return a list of datapoints', () => {
-          return ctx.ds.query(options).then((results: any) => {
-            expect(results.data.length).toBe(3);
-            expect(results.data[0].datapoints.length).toBe(2);
-            expect(results.data[0].target).toEqual('exceptions/server + client/city + Miami');
-            expect(results.data[0].datapoints[0][1]).toEqual(1504108800000);
-            expect(results.data[0].datapoints[0][0]).toEqual(10);
-            expect(results.data[0].datapoints[1][1]).toEqual(1504112400000);
-            expect(results.data[0].datapoints[1][0]).toEqual(20);
+            expect(results.data.length).toBe(2);
+            let data = results.data[0] as DataFrame;
+            expect(data.name).toEqual('exceptions/server{client/city="Miami"}');
+            expect(data.fields[0].values.length).toEqual(2);
+            expect(data.fields[1].values.get(0)).toEqual(1504108800000);
+            expect(data.fields[0].values.get(0)).toEqual(10);
+            expect(data.fields[1].values.get(1)).toEqual(1504112400000);
+            expect(data.fields[0].values.get(1)).toEqual(20);
+            data = results.data[1] as DataFrame;
+            expect(data.name).toEqual('exceptions/server{client/city="San Antonio"}');
+            expect(data.fields[0].values.length).toEqual(2);
+            expect(data.fields[1].values.get(0)).toEqual(1504108800000);
+            expect(data.fields[0].values.get(0)).toEqual(1);
+            expect(data.fields[1].values.get(1)).toEqual(1504112400000);
+            expect(data.fields[0].values.get(1)).toEqual(2);
           });
         });
       });
