@@ -1,19 +1,10 @@
 import _ from 'lodash';
+import { auto } from 'angular';
 import $ from 'jquery';
 import 'vendor/flot/jquery.flot';
 import 'vendor/flot/jquery.flot.gauge';
 import 'app/features/panel/panellinks/link_srv';
-import {
-  convertOldAngulrValueMapping,
-  getColorFromHexRgbOrName,
-  getDisplayProcessor,
-  getFlotPairs,
-  LegacyResponseData,
-} from '@grafana/ui';
 
-import kbn from 'app/core/utils/kbn';
-import config from 'app/core/config';
-import { MetricsPanelCtrl } from 'app/plugins/sdk';
 import {
   DataFrame,
   DisplayValue,
@@ -25,8 +16,19 @@ import {
   LinkModel,
   reduceField,
   ReducerID,
+  LegacyResponseData,
+  getFlotPairs,
+  getDisplayProcessor,
+  getColorFromHexRgbOrName,
+  PanelEvents,
 } from '@grafana/data';
-import { auto } from 'angular';
+
+import { convertOldAngularValueMapping } from '@grafana/ui';
+
+import { CoreEvents } from 'app/types';
+import kbn from 'app/core/utils/kbn';
+import config from 'app/core/config';
+import { MetricsPanelCtrl } from 'app/plugins/sdk';
 import { LinkSrv } from 'app/features/panel/panellinks/link_srv';
 import { getProcessedDataFrames } from 'app/features/dashboard/state/runRequest';
 
@@ -118,10 +120,9 @@ class SingleStatCtrl extends MetricsPanelCtrl {
     super($scope, $injector);
     _.defaults(this.panel, this.panelDefaults);
 
-    this.events.on('data-frames-received', this.onFramesReceived.bind(this));
-    this.events.on('data-error', this.onDataError.bind(this));
-    this.events.on('data-snapshot-load', this.onSnapshotLoad.bind(this));
-    this.events.on('init-edit-mode', this.onInitEditMode.bind(this));
+    this.events.on(CoreEvents.dataFramesReceived, this.onFramesReceived.bind(this));
+    this.events.on(PanelEvents.dataSnapshotLoad, this.onSnapshotLoad.bind(this));
+    this.events.on(PanelEvents.editModeInitialized, this.onInitEditMode.bind(this));
 
     this.useDataFrames = true;
 
@@ -150,10 +151,6 @@ class SingleStatCtrl extends MetricsPanelCtrl {
     this.refresh();
   }
 
-  onDataError(err: any) {
-    this.handleDataFrames([]);
-  }
-
   onSnapshotLoad(dataList: LegacyResponseData[]) {
     this.onFramesReceived(getProcessedDataFrames(dataList));
   }
@@ -182,13 +179,17 @@ class SingleStatCtrl extends MetricsPanelCtrl {
     }
 
     if (!fieldInfo) {
+      const processor = getDisplayProcessor({
+        config: {
+          mappings: convertOldAngularValueMapping(this.panel),
+          noValue: 'No Data',
+        },
+        theme: config.theme,
+      });
       // When we don't have any field
       this.data = {
-        value: 'No Data',
-        display: {
-          text: 'No Data',
-          numeric: NaN,
-        },
+        value: null,
+        display: processor(null),
       };
     } else {
       this.data = this.processField(fieldInfo);
@@ -242,7 +243,7 @@ class SingleStatCtrl extends MetricsPanelCtrl {
         ...fieldInfo.field.config,
         unit: panel.format,
         decimals: panel.decimals,
-        mappings: convertOldAngulrValueMapping(panel),
+        mappings: convertOldAngularValueMapping(panel),
       },
       theme: config.theme,
       isUtc: dashboard.isTimezoneUtc && dashboard.isTimezoneUtc(),
@@ -658,7 +659,7 @@ class SingleStatCtrl extends MetricsPanelCtrl {
 
     hookupDrilldownLinkTooltip();
 
-    this.events.on('render', () => {
+    this.events.on(PanelEvents.render, () => {
       render();
       ctrl.renderingCompleted();
     });
